
### load datasets and compile

load("data/res_complete.RData")

load("data/stats_null.RData")
load("data/stats_re.RData")
load("data/stats_dp.RData")
load("data/stats_knn.RData")
load("data/stats_pa.RData")
load("data/stats_rf.RData")
load("data/stats_mice.RData")
load("data/stats_bergm1.RData")
load("data/stats_bergm2.RData")

load("data/mlist_coefs.RData")
load("data/coef_null.RData")
load("data/coef_re.RData")
load("data/coef_pa.RData")
load("data/coef_dp.RData")
load("data/coef_knn.RData")
load("data/coef_rf.RData")
load("data/coef_mice.RData")
load("data/coef_bergm1.RData")
load("data/coef_bergm2.RData")

library(ggplot2)
library(dplyr)
library(xtable)


colnames(res_complete)[4:11]<-paste0("cs_",colnames(res_complete)[4:11])
tmp<-res_complete[c('ssize', 'sim', 'rep', 'cs_density', 'cs_reciprocity', 'cs_gwesp', 'cs_homophilyA', 'cs_homophilyB', 'cs_homophilyC')]
stats_all<-rbind(stats_null, stats_re, stats_dp,  stats_pa,stats_knn,stats_rf, stats_mice, stats_bergm1, stats_bergm2)
stats_all<-merge(stats_all, tmp, by=c('ssize', 'sim', 'rep'))


stats_all <- stats_all %>% mutate (
    density_diff=density-cs_density,
    reciprocity_diff=reciprocity-cs_reciprocity,
    gwesp_diff=gwesp-cs_gwesp,
    homophilyA_diff=homophilyA-cs_homophilyA,
    homophilyB_diff=homophilyB-cs_homophilyB,
    homophilyC_diff=homophilyC-cs_homophilyC
)

stats_all<-stats_all[complete.cases(stats_all),]
levels(stats_all$tp)[levels(stats_all$tp)=="cell"] <- "tie"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="dp"] <- "DP"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="knn"] <- "KNN"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="mice"] <- "MICE"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="bergm1"] <- "BERGM1"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="bergm2"] <- "BERGM2"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="rf"] <- "RF"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="re"] <- "RE"
levels(stats_all$imp_method)[levels(stats_all$imp_method)=="pa"] <- "PA"




mlist_coefs$imp_method="none"
mlist_coefs$imp_num="none"
coef_all<-rbind(coef_null, coef_re, coef_dp, coef_pa, coef_knn, coef_rf,coef_mice, coef_bergm1, coef_bergm2, mlist_coefs)
coef_all<-merge(coef_all, res_complete[c("ssize", "sim",'rep', "c_edges", "c_mutual", "c_gwesp", "c_nodematchB", "c_nodematchC", "c_nodecovA", "c_nodefactorB2", "c_nodecovC")],
                by=c('ssize', 'sim', 'rep'))


coef_all <- coef_all %>% mutate (
  edges_diff=edges-c_edges,
  mutual_diff=mutual-c_mutual,
  gwesp_diff=gwesp-c_gwesp,
  nodematchB_diff=nodematchB-c_nodematchB,
  nodematchC_diff=nodematchC-c_nodematchC,
  nodecovA_diff=nodecovA-c_nodecovA,
  nodefactorB2_diff=nodefactorB2-c_nodefactorB2,
  nodecovC_diff=nodecovC-c_nodecovC,
)

coef_all<-coef_all[complete.cases(coef_all),]
levels(coef_all$tp)[levels(coef_all$tp)=="cell"] <- "tie"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="dp"] <- "DP"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="knn"] <- "KNN"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="mice"] <- "MICE"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="bergm1"] <- "BERGM1"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="bergm2"] <- "BERGM2"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="rf"] <- "RF"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="re"] <- "RE"
levels(coef_all$imp_method)[levels(coef_all$imp_method)=="pa"] <- "PA"




rmse<-function(x, comp){
  x<-x[!is.na(x)]
  comp<-comp[!is.na(x)]
  return((sqrt(sum(x^2)/length(x)))/abs(mean(comp, na.rm=T)))
  #return((sqrt(sum(x^2)/length(x))))
}




### visualizations


# complete network
res_complete %>%  group_by(sim, ssize) %>% summarize(density=mean(cs_density),  gwesp=mean(cs_gwesp),reciprocity=mean(cs_reciprocity), homophilyA=mean(cs_homophilyA), homophilyB=mean(cs_homophilyB), homophilyC=mean(cs_homophilyC)) %>% xtable() 

res_complete %>%  group_by(sim, ssize) %>% summarize(edges=mean(c_edges),  gwesp=mean(c_gwesp),mutual=mean(c_mutual), nodematchB=mean(c_nodematchB), nodematchC=mean(c_nodematchC), nodecovA=mean(c_nodecovA), nodefactorB=mean(c_nodefactorB2), nodecovC=mean(c_nodecovC)) %>% xtable()



# link reconstruction
stats_all  %>% group_by(sim, imp_method) %>% summarize(mean(TPR), mean(TNR)) %>% View()


# see if data can be aggregated, can aggregate across mech and sim, prop and tp difference is large
df1 <- stats_all %>% filter(ssize==100, sim==1)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(stats=mean(TPR))

df1 %>% filter(tp=="tie", mech=="mnar1") %>% ggplot(aes(x=prop, y=stats, color=imp_method)) + 
  geom_point() +
  geom_line(aes(linetype=imp_method))


df1 <- stats_all%>% group_by(tp, prop, mech, imp_method) %>% summarize(TPR=mean(TPR), TNR=mean(TNR)) %>% mutate(method=imp_method) %>% filter (mech!="mar") %>% filter (mech!="mnar2")



pdf("plots/correct_tie.pdf", width=10, height=5)
ggplot(df1, aes(x=prop, y=TPR,  color = method)) +
  geom_point(size=0.7)+
  geom_line(size=0.6, aes(linetype=method), alpha=0.9)+
  facet_grid(mech ~ tp) +
  theme(text = element_text(size = 15),
        panel.background = element_blank(),
        panel.grid.major=element_line(size=0.05, color="gray", linetype="dashed"),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("proportion of correctly imputed present ties")
dev.off()


pdf("plots/correct_notie.pdf", width=10, height=5)
ggplot(df1, aes(x=prop, y=TNR,  color = method)) +
  geom_point(size=0.7)+
  geom_line(size=0.6, aes(linetype=method), alpha=0.9)+
  facet_grid(mech ~ tp) +
  theme(text = element_text(size = 15),
        panel.background = element_blank(),
        panel.grid.major=element_line(size=0.05, color="gray", linetype="dashed"),
        panel.border = element_rect(fill = NA)) +     
  xlab("missing proportion")+
  ylab("proportion of correctly imputed absent ties") 
dev.off()




# degree corr

df1 <- stats_all %>% group_by(imp_method, sim, ssize, mech, prop, tp) %>% summarize(ind=mean(corIn), outd=mean(corOut)) %>% filter(sim==4, ssize==100)


df1 %>% filter(tp=="tie", mech=="mar") %>% ggplot(aes(x=prop, y=ind, color=imp_method)) + 
  geom_point() +
  geom_line(aes(linetype=imp_method))



df1 <- stats_all%>% group_by(tp, prop, mech, imp_method) %>% summarize(indegree=mean(corIn), outdegree=mean(corOut)) %>% mutate(method=imp_method) %>% filter (mech!="mar") %>% filter (mech!="mnar2")


pdf("plots/indegree_correlation.pdf", width=10, height=5)
ggplot(df1, aes(x=prop, y=indegree,  color = method)) +
  geom_point(size=0.7)+
  geom_line(size=0.6, aes(linetype=method), alpha=0.7)+
  facet_grid(mech~tp) +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.grid.major=element_line(size=0.05, color="gray", linetype="dashed"),
        panel.border = element_rect(fill = NA)) +     
  xlab("missing proportion")+
  ylab("indegree correlation") 
dev.off()

pdf("plots/outdegree_correlation.pdf", width=10, height=5)
ggplot(df1, aes(x=prop, y=outdegree,  color = method)) +
  geom_point(size=0.7)+
  geom_line(size=0.6, aes(linetype=method), alpha=0.7)+
  facet_grid(mech~tp) +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.grid.major=element_line(size=0.05, color="gray", linetype="dashed"),
        panel.border = element_rect(fill = NA)) +     
  xlab("missing proportion")+
  ylab("outdegree correlation") 
dev.off()



# network statistics
nrmsedf<- stats_all %>% group_by(imp_method, ssize) %>% summarize(density=rmse(density_diff, cs_density), reciprocity=rmse(reciprocity_diff, cs_reciprocity), gwesp=rmse(gwesp_diff, cs_gwesp),  homophilyA=rmse(homophilyA_diff, cs_homophilyA), homophilyB=rmse(homophilyB_diff, cs_homophilyB), homophilyC=rmse(homophilyC_diff, cs_homophilyC)
)

nrmsedf %>% xtable()


df1 <- stats_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(density_diff, cs_density))

pdf("plots/density_stats.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()



df1 <- stats_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(reciprocity_diff, cs_reciprocity))

pdf("plots/recip_stats.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()



df1 <- stats_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(gwesp_diff, cs_gwesp))

pdf("plots/gwesp_stats.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()


df1 <- stats_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(homophilyA_diff, cs_homophilyA))

pdf("plots/homA_stats.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()

df1 <- stats_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(homophilyB_diff, cs_homophilyB))

pdf("plots/homB_stats.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()


df1 <- stats_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(homophilyC_diff, cs_homophilyC))

pdf("plots/homC_stats.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()


mins <- stats_all %>% group_by(imp_method, mech, tp, sim) %>% summarize(density=rmse(density_diff, cs_density), reciprocity=rmse(reciprocity_diff, cs_reciprocity), gwesp=rmse(gwesp_diff, cs_gwesp),  homophilyA=rmse(homophilyA_diff, cs_homophilyA), homophilyB=rmse(homophilyB_diff, cs_homophilyB), homophilyC=rmse(homophilyC_diff, cs_homophilyC)) %>% group_by(sim, mech, tp)

density <- mins %>%  slice(which.min(density))
density = density[,c("imp_method", "mech", "tp", "sim")]
colnames(density) <- c("density", "mechanism", "type", "simulation")

recip <- mins %>%  slice(which.min(reciprocity))
recip = recip[,c("imp_method", "mech", "tp", "sim")]
colnames(recip) <- c("reciprocity", "mechanism", "type", "simulation")

gwesp <- mins %>%  slice(which.min(gwesp))
gwesp = gwesp[,c("imp_method", "mech", "tp", "sim")]
colnames(gwesp) <- c("gwesp", "mechanism", "type", "simulation")

homophilyA <- mins %>%  slice(which.min(homophilyA))
homophilyA = homophilyA[,c("imp_method", "mech", "tp", "sim")]
colnames(homophilyA) <- c("homophilyA", "mechanism", "type", "simulation")

homophilyB <- mins %>%  slice(which.min(homophilyB))
homophilyB = homophilyB[,c("imp_method", "mech", "tp", "sim")]
colnames(homophilyB) <- c("homophilyB", "mechanism", "type", "simulation")


homophilyC <- mins %>%  slice(which.min(homophilyC))
homophilyC = homophilyC[,c("imp_method", "mech", "tp", "sim")]
colnames(homophilyC) <- c("homophilyC", "mechanism", "type", "simulation")

stats <- cbind(density[2:4], density[1], recip[,1], gwesp[,1], homophilyA[,1],homophilyB[,1], homophilyC[,1])

stats %>% xtable()



# ergm coefficients

nrmsedf<- coef_all %>% group_by(imp_method, ssize) %>% summarize(edges=rmse(edges_diff, c_edges), mutual=rmse(mutual_diff, c_mutual), gwesp=rmse(gwesp_diff, c_gwesp),  nodematchB=rmse(nodematchB_diff, c_nodematchB), nodematchC=rmse(nodematchC_diff, c_nodematchC), nodecovA=rmse(nodecovA_diff, c_nodecovA),nodefactorB=rmse(nodefactorB2_diff, c_nodefactorB2),nodecovC=rmse(nodecovC_diff, c_nodecovC), 
)

nrmsedf %>% xtable()

df1 <- coef_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(edges_diff, c_edges))

pdf("plots/edges_coef.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()

df1 <- coef_all %>% filter(ssize==100)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(mutual_diff, c_mutual))

pdf("plots/mutual_coef.pdf", width=10, height=12)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()

df1 <- coef_all %>% filter(ssize==100, sim==4)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(gwesp_diff, c_gwesp))

pdf("plots/gwesp_coef.pdf", width=10, height=6)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()

df1 <- coef_all %>% filter(ssize==100, sim!=1)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(nodematchB_diff, c_nodematchB))

pdf("plots/nodematchB_coef.pdf", width=10, height=10)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()

df1 <- coef_all %>% filter(ssize==100,sim!=1)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(nodematchC_diff, c_nodematchC))

pdf("plots/nodematchC_coef.pdf", width=10, height=10)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()

df1 <- coef_all %>% filter(ssize==100, sim!=1, sim!=2)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(nodecovA_diff, c_nodecovA))

pdf("plots/nodecovA_coef.pdf", width=10, height=8)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()


df1 <- coef_all %>% filter(ssize==100,sim!=1, sim!=2)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(nodefactorB2_diff, c_nodefactorB2))

pdf("plots/nodefactorB_coef.pdf", width=10, height=8)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()


df1 <- coef_all %>% filter(ssize==100,sim!=1, sim!=2)%>% group_by(sim, tp, mech, prop, imp_method) %>% summarize(rmse= rmse(nodecovC_diff, c_nodecovC))

pdf("plots/nodecovC_coef.pdf", width=10, height=8)
ggplot(df1, aes(x=prop, y=mech, fill= rmse)) +
  geom_tile()+
  facet_grid(sim + tp ~ imp_method)+
  scale_fill_gradient(name = "NRMSE",
                      low = "#FFFFFF",
                      high = "#0f3c69") +
  theme(text = element_text(size = 12),
        panel.background = element_blank(),
        panel.border = element_rect(fill = NA)) +
  xlab("missing proportion")+
  ylab("missing mechanism")
dev.off()


mins <- coef_all %>% filter(imp_method!="none") %>% group_by(imp_method, mech, tp, sim) %>% summarize(edges=rmse(edges_diff, c_edges), mutual=rmse(mutual_diff, c_mutual), gwesp=rmse(gwesp_diff, c_gwesp),  nodematchB=rmse(nodematchB_diff, c_nodematchB), nodematchC=rmse(nodematchC_diff, c_nodematchC), nodecovA=rmse(nodecovA_diff, c_nodecovA),nodefactorB=rmse(nodefactorB2_diff, c_nodefactorB2),nodecovC=rmse(nodecovC_diff, c_nodecovC)) %>% group_by(sim, mech, tp)

edges <- mins %>%  slice(which.min(edges))
edges = edges[,c("imp_method", "mech", "tp", "sim")]
colnames(edges) <- c("edges", "mechanism", "type", "simulation")

mutual <- mins %>%  slice(which.min(mutual))
mutual = mutual[,c("imp_method", "mech", "tp", "sim")]
colnames(mutual) <- c("mutual", "mechanism", "type", "simulation")

gwesp <- mins %>%  slice(which.min(gwesp))
gwesp = gwesp[,c("imp_method", "mech", "tp", "sim")]
colnames(gwesp) <- c("gwesp", "mechanism", "type", "simulation")

nodematchB <- mins %>%  slice(which.min(nodematchB))
nodematchB = nodematchB[,c("imp_method", "mech", "tp", "sim")]
colnames(nodematchB) <- c("nodematchB", "mechanism", "type", "simulation")

nodematchC <- mins %>%  slice(which.min(nodematchC))
nodematchC = nodematchC[,c("imp_method", "mech", "tp", "sim")]
colnames(nodematchC) <- c("nodematchC", "mechanism", "type", "simulation")


nodecovA <- mins %>%  slice(which.min(nodecovA))
nodecovA = nodecovA[,c("imp_method", "mech", "tp", "sim")]
colnames(nodecovA) <- c("nodecovA", "mechanism", "type", "simulation")

nodefactorB <- mins %>%  slice(which.min(nodefactorB))
nodefactorB = nodefactorB[,c("imp_method", "mech", "tp", "sim")]
colnames(nodefactorB) <- c("nodefactorB", "mechanism", "type", "simulation")


nodecovC <- mins %>%  slice(which.min(nodecovC))
nodecovC = nodecovC[,c("imp_method", "mech", "tp", "sim")]
colnames(nodecovC) <- c("nodecovC", "mechanism", "type", "simulation")


stats <- cbind(edges[2:4], edges[1], mutual[1], gwesp[1], nodematchB[1], nodematchC[1], nodecovA[1], nodefactorB[1], nodecovC[1])

stats %>% xtable()




######## miscs ##############
coef_all %>% group_by(sim, ssize, mech, tp, prop, imp_method) %>% count() %>% View()

stats_null %% group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()


stats_mice %>% group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) 

stats_re %>%  group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()

stats_dp %>%  group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()

stats_knn %>%  group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()

stats_pa %>%  group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()

stats_rf %>%  group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()

stats_bergm2[complete.cases(stats_bergm2),] %>%  group_by(sim, ssize) %>% summarize(TPR=mean(TPR),TNR=mean(TNR), incor=mean(corIn), outcor=mean(corOut), density=mean(density),  gwesp=mean(gwesp),"reciprocity"=mean(reciprocity), homophilyA=mean(homophilyA), "homophilyB"=mean(homophilyB), "homophilyC"=mean(homophilyC)) %>% View()
 