
library(sna)
library(ape)
library(R.utils)
library(ergm)

imp_acc <- function(data_missing, data_full, data_impute){
  missindex <- which(is.na(data_missing))
  acc <- sum(data_full[missindex]==data_impute[missindex])/length(missindex)
  return(acc)
}



confusion_matrix <- function(data_missing, data_full, data_impute){
  missindex <- which(is.na(data_missing))
  
  
  
  missindex <- which(is.na(data_missing))
  equalind <- which(data_impute[missindex] == data_full[missindex])
  TP <- sum(data_impute[missindex][equalind] == 1)
  TN <- sum(data_impute[missindex][equalind] == 0)
  unequalind <- which(data_impute[missindex] != data_full[missindex])
  FP <- sum(data_impute[missindex][unequalind] == 1)
  FN <- sum(data_impute[missindex][unequalind] == 0)
  
  cmtable <- matrix(c(0,0,0,0), nrow=2)
  # TN FN
  # FP TP
  cmtable[1,1]<-TN
  cmtable[1,2]<-FN
  cmtable[2,1]<-FP
  cmtable[2,2]<-TP
  return(list("TP"=TP, "FP"=FP, "TN"=TN, "FN"=FN, "TNR"=TN/(TN+FP), "TPR"=TP/(TP+FN)))
  # colsum <- colSums(cmtable)
  # cmtable[,1]<-cmtable[,1]/colsum[1]
  # cmtable[,2]<-cmtable[,2]/colsum[2]
  # cmtable[is.na(cmtable)]<-0
 
}

degcor<-function(compnet, net){
      compnetin<-colSums(compnet)
      compnetout<-rowSums(compnet)

      impin<-colSums(net)
      impout<-rowSums(net)

      corin=(cor(compnetin, impin))
      corout=(cor(compnetout, impout))
      return(c(corin, corout))
}


# library(ape)
netstats <- function(netdata, va, vb, vc){
 recip<-grecip(netdata, measure="edgewise")
 trans<-gtrans(netdata)
 dens<-gden(netdata)
 homA<-Moran.I(va, netdata)$observed
 homC<-Moran.I(vc, netdata)$observed
 
 net <- as.network(netdata)
 set.vertex.attribute(net, "va", va)
 set.vertex.attribute(net, "vb", vb)
 set.vertex.attribute(net, "vc", vc)
 stats<-summary(net ~ edges + gwesp + triangle + nodematch("vb"))
 
 triangle <- stats[length(stats)-1]/count_pos_triangles(length(va))
 gwesp <- sum(stats[2:(length(stats)-2)]*c(1:(length(stats)-3)))/(sum(netdata)*(nrow(netdata)-2))
 homB <- stats[length(stats)]/stats[1]
 
 
 
 
 return(list("reciprocity"=recip,
             "transitivity"=trans,
             "density"=dens,
             "triangle"=triangle,
             "gwesp"=gwesp,
             "homophilyA"=homA,
             "homophilyB"=homB,
             "homophilyC"=homC))
}

count_pos_gwesp<-function(n){
  num=0
  for (i in 1:n){
    for (j in 1:n){
      num=num+(n-2);
    }
  }
  return(num)
}


count_pos_triangles<-function(n){
  num=0
  for (i in 1:n){
    for (j in 1:n){
      for (k in 1:n){
        if (i!=j && i!=k && j!=k){
          num=num+2 # +2 because (i,j), (j,k), (k,i) and (i,j), (j,k), (i,k) both count  
        }
      }
    }
  }
  return (num)
}



ergmcoef<-function(netdat, va, vb, vc){
  net <- as.network(netdat) # 
  set.vertex.attribute(net, "va", va)
  set.vertex.attribute(net, "vb", vb)
  set.vertex.attribute(net, "vc", vc)
  
  
  # ERGM
  m1<-NA
  
  withTimeout( 
    {tryCatch({
      m1 <- summary(ergm(net ~ edges + mutual +  gwesp(0.5, fixed=T) + nodematch("vb") + nodematch("vc") + nodecov("va") + nodefactor("vb") + nodecov("vc")))
    },error = function(e){NULL})},
    timeout = 1800,
    onTimeout = "silent")
  
  if (is.na(m1)){
    return(list("edges"=NA,
                "mutual"=NA,
                "gwesp"=NA,
                "nodematchB"=NA,
                "nodematchC"=NA,
                "nodecovA"=NA,
                "nodefactorB2"=NA,
                "nodecovC"=NA
    ))
  }
  
  return(list("edges"=coef(m1)["edges",1],
         "mutual"=coef(m1)["mutual",1],
        "gwesp"=coef(m1)["gwesp.fixed.0.5",1],
        "nodematchB"=coef(m1)["nodematch.vb",1],
        "nodematchC"=coef(m1)["nodematch.vc",1],
        "nodecovA"=coef(m1)["nodecov.va",1],
        "nodefactorB2"=coef(m1)["nodefactor.vb.2",1],
        "nodecovC"=coef(m1)["nodecov.vc",1]
  ))
}


